@@ -23,6 +23,7 @@
 #include "dialog.h"
 #include "layout.h"
 #include "gdesktop.h"
+#include "gmain.h"
 #include "../vfs/vfs.h"
 
 static char *panelize_section = "Panelize";
@@ -150,7 +151,7 @@ gnome_close_panel (GtkWidget *widget, WPanel *panel)
 }
 
 static void
-set_view_type (GtkWidget *widget, WPanel *panel, enum list_types type)
+set_list_type (GtkWidget *widget, WPanel *panel, enum list_types type)
 {
 	int i;
 
@@ -173,7 +174,7 @@ set_view_type (GtkWidget *widget, WPanel *panel, enum list_types type)
 	if (panel->list_type == type)
 		return;
 
-	/* Set the list type */
+        /* Set the list type */
 
 	panel->list_type = type;
 	set_panel_formats (panel);
@@ -207,25 +208,25 @@ set_view_type (GtkWidget *widget, WPanel *panel, enum list_types type)
 void
 gnome_icon_view_cmd (GtkWidget *widget, WPanel *panel)
 {
-	set_view_type (widget, panel, list_icons);
+	set_list_type (widget, panel, list_icons);
 }
 
 void
 gnome_brief_view_cmd (GtkWidget *widget, WPanel *panel)
 {
-	set_view_type (widget, panel, list_brief);
+	set_list_type (widget, panel, list_brief);
 }
 
 void
 gnome_detailed_view_cmd (GtkWidget *widget, WPanel *panel)
 {
-	set_view_type (widget, panel, list_full);
+	set_list_type (widget, panel, list_full);
 }
 
 void
 gnome_custom_view_cmd (GtkWidget *widget, WPanel *panel)
 {
-	set_view_type (widget, panel, list_user);
+	set_list_type (widget, panel, list_user);
 }
 
 static void
@@ -785,6 +786,13 @@ gnome_mkdir_cmd (GtkWidget *widget, WPanel *panel)
 	mkdir_cmd (panel);
 }
 
+void
+gnome_newfile_cmd (GtkWidget *widget, WPanel *panel)
+{
+	mc_chdir (panel->cwd);
+	gmc_edit ("");
+}
+
 static void
 dentry_apply_callback(GtkWidget *widget, int page, gpointer data)
 {
