@@ -13,12 +13,13 @@
 #include <orb/orbit.h>
 
 
-/* The ORB */
+/* The ORB and the POA */
 extern CORBA_ORB orb;
+PortableServer_POA poa;
 
 
 int corba_init_server (void);
-void corba_create_window (const char *dir);
+void corba_create_window (char *dir);
 
 
 #endif
