@@ -144,7 +144,7 @@
 #include "gsession.h"
 #endif
 
-/* "$Id: main.c,v 1.99 1999/08/31 22:55:19 unammx Exp $" */
+/* "$Id: main.c,v 1.101 1999/09/19 23:09:12 norbert Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -2790,7 +2790,7 @@ init_corba_with_args (int *argc, char **argv, poptContext *ctx)
 
 #ifndef HAVE_CORBA
 void
-corba_create_window (const char *startup_dir)
+corba_create_window (char *startup_dir)
 {
 	/* nothing */
 }
@@ -2949,6 +2949,7 @@ main (int argc, char *argv [])
     setlocale (LC_ALL, "");
     bindtextdomain ("mc", LOCALEDIR);
     textdomain ("mc");
+    mad_init ();
 #if 0
     /* This is here to debug startup stuff */
     {
